@@ -12,14 +12,17 @@
 #'
 #' @description
 #' A classification task for the [mlbench::Zoo] data set.
+#' Rownames are stored as variable `"..rownames` with column role `"name"`.
 #'
 #' @template seealso_task
 NULL
 
 load_task_zoo = function(id = "zoo") {
-  b = as_data_backend(load_dataset("Zoo", "mlbench", keep_rownames = TRUE))
+  b = as_data_backend(load_dataset("Zoo", "mlbench", keep_rownames = TRUE), keep_rownames = "animal")
   task = TaskClassif$new(id, b, target = "type")
   b$hash = task$man = "mlr3::mlr_tasks_zoo"
+  task$col_roles$name = "animal"
+  task$col_roles$feature = setdiff(task$col_roles$feature, "animal")
   task
 }
 
