@@ -26,20 +26,6 @@ allow_partial_matching = list(
   warnPartialMatchDollar = FALSE
 )
 
-# determines if execution via future will be running locally or remotely
-use_future = function() {
-  if (!isNamespaceLoaded("future") || inherits(future::plan(), "uniprocess")) {
-    return(FALSE)
-  }
-
-  if (!requireNamespace("future.apply", quietly = TRUE)) {
-    lg$warn("Package 'future.apply' could not be loaded. Parallelization disabled.")
-    return(FALSE)
-  }
-
-  return(TRUE)
-}
-
 get_progressor = function(n, label = NA_character_) {
   if (!isNamespaceLoaded("progressr")) {
     return(NULL)
